@@ -1,7 +1,7 @@
 /*
- * $Id: radacct.c,v 1.8 1996/03/15 13:53:04 lf Exp $
+ * $Id: radacct.c,v 1.9 1996/03/18 23:20:19 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at in5y050@public.uni-hamburg.de 
@@ -10,10 +10,10 @@
  */
 
 static char	rcsid[] =
-		"$Id: radacct.c,v 1.8 1996/03/15 13:53:04 lf Exp $";
+		"$Id: radacct.c,v 1.9 1996/03/18 23:20:19 lf Exp $";
 
 static char	copyright_1[] =
-		"$Copyright: (C) 1995 Lars Fenneberg $";
+		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
 
 static char	copyright_2[] =
 		"$Parts: (C) 1992 Livingston Enterprises, Inc. $";
@@ -40,6 +40,8 @@ University of Michigan and Merit Network, Inc. All Rights Reserved $";
 #include	<syslog.h>
 
 #include	"radius.h"
+#include	"messages.h"
+#include	"pathnames.h"
 
 static char *pname;
 
@@ -71,7 +73,7 @@ main (int argc, char **argv)
 
 	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
 
-	if (rc_read_config(RADIUSCLIENT_CONF) != 0)
+	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
 		exit(ERROR_RC);
 	
 	if (rc_read_dictionary(conf_dictionary) != 0)
@@ -107,11 +109,11 @@ main (int argc, char **argv)
 		result = rc_acct(client_port, send);
 		if (result == OK_RC)
 		{
-			rc_log(LOG_NOTICE, "RADIUS accounting OK");
+			rc_log(LOG_NOTICE, SC_ACCT_OK);
 		}
 		else
 		{
-			rc_log(LOG_NOTICE, "RADIUS accounting failed (RC=%i)", result);
+			rc_log(LOG_NOTICE, SC_ACCT_FAILED, result);
 		}
 		rc_avpair_free(send);
 	}
