@@ -1,5 +1,5 @@
 /*
- * $Id: radlogin.c,v 1.13 1996/03/18 23:20:19 lf Exp $
+ * $Id: radlogin.c,v 1.14 1996/03/21 21:20:19 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -10,7 +10,7 @@
  */
 
 static char	rcsid[] =
-		"$Id: radlogin.c,v 1.13 1996/03/18 23:20:19 lf Exp $";
+		"$Id: radlogin.c,v 1.14 1996/03/21 21:20:19 lf Exp $";
 
 static char	copyright_1[] =
 		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
@@ -150,6 +150,11 @@ int auth_radius(UINT4 client_port, char *username, char *passwd)
 
 	
 	result = rc_auth(client_port, send, &received, msg);
+
+	/* suppress the message if the radiusd just wants to saw something
+	   that we're going to say anyway (works for Merit radiusd) */
+	if (msg && (*msg != '\0') && strcmp("Authentication failure\r\n", msg))
+		rc_log(LOG_NOTICE, "%s%s", SC_REPLY_PREFIX, msg);
 	
 	if (result == OK_RC)
 	{
