@@ -1,7 +1,7 @@
 /*
- * $Id: radstatus.c,v 1.5 1996/03/15 13:53:04 lf Exp $
+ * $Id: radstatus.c,v 1.6 1996/03/18 23:20:19 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at in5y050@public.uni-hamburg.de 
@@ -10,10 +10,10 @@
  */
 
 static char	rcsid[] =
-		"$Id: radstatus.c,v 1.5 1996/03/15 13:53:04 lf Exp $";
+		"$Id: radstatus.c,v 1.6 1996/03/18 23:20:19 lf Exp $";
 
 static char	copyright_1[] =
-		"$Copyright: (C) 1995 Lars Fenneberg $";
+		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
 
 static char	copyright_2[] =
 		"$Parts: (C) 1992 Livingston Enterprises, Inc. $";
@@ -30,6 +30,7 @@ University of Michigan and Merit Network, Inc. All Rights Reserved $";
 #include	<stdlib.h>
 
 #include	"radius.h"
+#include	"pathnames.h"
 
 static char *pname;
 
@@ -57,7 +58,7 @@ void main (int argc, char **argv)
 
 	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
 
-	if (rc_read_config(RADIUSCLIENT_CONF) != 0)
+	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
 		exit(ERROR_RC);
 	
 	if (rc_read_dictionary(conf_dictionary) != 0)
